@@ -21,5 +21,20 @@ class FailedAuthException(Exception):
 
 
 class BadRequestException(Exception):
+    def __init__(self, msg=''):
+        super(BadRequestException, self).__init__(msg or "Check your config and query data for bad or missing values.")
+
+
+class TermsException(Exception):
     def __init__(self):
-        super(BadRequestException, self).__init__("Check your config and query data for bad or missing values.")
+        super(TermsException, self).__init__("Re-submit your request if you have consent to request the customer's personal credit.")
+
+
+class IncompleteOwnerException(Exception):
+    def __init__(self, msg):
+        super(IncompleteOwnerException, self).__init__(msg)
+
+
+class IncompleteBusinessException(Exception):
+    def __init__(self, msg):
+        super(IncompleteBusinessException, self).__init__(msg)
\ No newline at end of file
